Crate serde_seeded_derive

Crate serde_seeded_derive 

This is a companion crate for serde-seeded defining the SerializeSeeded and DeserializeSeeded derive macros. It is not recommended to use this crate directly. Use the serde-seeded crate directly instead with the derive feature enabled.

Derive Macros

DeserializeSeeded
Derive macro implementing the DeserializeSeeded trait automatically.
SerializeSeeded
Derive macro implementing the SerializeSeeded trait automatically.